@@ -2,9 +2,9 @@ import binascii
 import math
 
 from construct import (Adapter, Array, Bytes, Checksum, Computed, Const,
-                       GreedyBytes, Int8ul, Int16ul, Int32ub, Int32ul,
-                       Optional, PaddedString, Prefixed, PrefixedArray,
-                       RawCopy, Rebuild, Struct, len_, this)
+                       Int8ul, Int16ul, Int32ub, Int32ul, Optional,
+                       PaddedString, Prefixed, PrefixedArray, RawCopy, Rebuild,
+                       Struct, len_, this)
 
 
 def compute_bit_length(ctx):
